@@ -40,7 +40,7 @@ class Stream:
         return uuid.uuid4().hex
 
     def generateMessage(self):
-        message = Context(extra={}, request_id=self.generateRequestId())
+        message = Context(extra=json.dumps({}), request_id=self.generateRequestId())
         return message
 
     def sendMessage(self, data, message):
@@ -77,7 +77,7 @@ class Stream:
                         self.client.xack(queue, "default", mid)
                         requestId = data["id"]
                         extra = data["extra"]
-                        context = Context(extra=extra, request_id=requestId)
+                        context = Context(extra=extra, request_id=requestId, args={})
                         try:
                             for k, v in data.items():
                                 if k.startswith("in") and k[-1].isdigit():
